﻿window.onload = function () {
    var app = new Vue({
        el: '#app',
        data: {
        }
    });
};

Vue.component('vod_grid', {
    data: function () {        
        return {
            viewType: String,
            summaryWithTitle: Boolean,
            listItems: [],
            gridItems: [], 
            group: null,
            cancelledRecording: null,
            showNewIndicator: false, 
            confirmOnDelete: true
        }
    },
    props: {
        list: String,
        view: String,        
    },

    template: '<div id="vodList" >\
                    <div class="row">\
                        <div v-for="(item, index) in gridItems" class="col-lg-2 col-sm-3 col-4 row-no-padding focusable">\
                            <div id="recording" @click="trigger({index})" class="recording-grid-item bg-light">\
                                <div class="thumbnail-container">\
                                    <img class="thumbnail img-fluid" :src="item.artworkURL" onerror="coverLoadError(this);">\
                                    <button type="button" class="btn btn-primary btn-sm float-button" @click.stop="download({ index })"><i class="fas fa-download"></i></button>\
                                </div>\
                                <div v-if="showPeriod" class="caption-btm text-center">\
                                    <p>{{ item.name }}<br><span class="text-secondary">{{ item.readableTime }}</span></p>\
                                </div>\
                                <div v-if="showPeriod == false" class="caption-btm text-center">\
                                    <p>{{ item.name }}</p>\
                                </div>\
                            </div>\
                        </div>\
                    </div>\
                </div>',

    mounted: function () {
        var self = this;        

        window.addEventListener('resize', function () {
            self.handleResize();
        });
    },
    computed: {
        showPeriod: function () {
            return this.summaryWithTitle;
        }
    },
    watch: {
        'messages': function (val, oldVal) {
            console.log("message: " + val);
        },
    },
    methods: {
        trigger(args) {            
            if (this.gridItems.length > 0) {
                var name = this.gridItems[args.index].name;                
                var id = this.gridItems[args.index].ID;
                var source = this.gridItems[args.index].source;
                var artworkURL = this.gridItems[args.index].artworkURL;
                if (source.includes('vod-')) {
                    window.location.href = 'player.html?vod_id=' + id + '&vod_artwork=' + encodeURIComponent(artworkURL) + '&title=' + encodeURIComponent(name) + "&delay=true";
                } else {
                    window.location.href = 'player.html?vod_id=' + id + '&vod_artwork=' + encodeURIComponent(artworkURL) + '&title=' + encodeURIComponent(name);
                }
            }            
        },
        handleResize() {
            var captionWidth = $(".caption-btm").width();
            var captionHeight = $(".caption-btm").height();
            var artworkHeight = ((captionWidth / 16) * 9);
            var recordingHeight = artworkHeight + "px";
            $(".thumbnail").css("height", recordingHeight);                
            $(".thumbnail").css("width", captionWidth);                
            $(".thumbnail-container").css("min-height", recordingHeight);                
            $(".thumbnail-container").css("max-height", recordingHeight);                
        },
        reload() {
            var self = this;
            if (self.group != null) {
                self.showNamedList(self.group);
            } 
        },
        download(args) {
            var self = this;
            var item = self.gridItems[args.index];
            var id = item.ID;
            var url = 'services/service?method=vod.download&vod_id=' + id + '&format=json';
            $.getJSON(url, function (data) {
                
            });
            showMessage("Downloading", "This video has been queued for downloaded, and will be available as a recording soon");
        },
        showNamedList(name) {
            var self = this;

            self.filter = "all";
            self.viewType = "list";
            self.group = name;

            var url = 'services/service?method=vod.list&filter=' + encodeURIComponent(self.group) + '&format=json';
            $.getJSON(url, function (data) {
                self.gridItems = data;
                self.listItems = [];                
            });
        }
    }
});
